"""
Create DataFrame string representations that can be used to create new DataFrames.
"""


import pandas as pd


ALIAS = "pd"


def pdrepr(df: pd.DataFrame) -> str:
    """Create DataFrame string representation that can be used to create a new DataFrame.

    Args:
        df: DataFrame to serialize

    Returns:
        String containing valid Python code that can be pasted into a script file or interpreter,
        or passed to eval(), thereby creating a DataFrame similar to the original.

    Example:
        string_repr = pdrepr(my_df)
        new_df = eval(string_repr)
    """

    index_columns = df.index.names
    df = df.reset_index()
    df = df.drop("index", axis=1, errors="ignore")
    d = df.to_dict(orient="list")
    string = f"{ALIAS}.DataFrame({repr(d)})"
    if sum([idx is not None for idx in index_columns]):
        string += f".set_index({index_columns})"
    return string



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pdrepr']

package_data = \
{'': ['*']}

install_requires = \
['pandas>=1.2.2,<2.0.0']

setup_kwargs = {
    'name': 'pdrepr',
    'version': '0.1.1',
    'description': 'eval-able string representation of pandas objects',
    'long_description': "# pdrepr\n\npdrepr takes a pandas DataFrame as input, and *attempts* to output a string that, when passed to Python's built-in \n`eval()`, will reproduce the original DataFrame. Supports multiindices for rows and columns, at least for the relatively\nsimple cases I have tested. DataFrames with datatypes other than strings, ints and floats should work if their \n``_repr__()`` method also returns a string that can be passed to `eval()`, resulting in a similar object.  \n\n![Testing and linting](https://github.com/danhje/pdrepr/workflows/Test%20And%20Lint/badge.svg)\n[![codecov](https://codecov.io/gh/danhje/pdrepr/branch/master/graph/badge.svg)](https://codecov.io/gh/danhje/pdrepr)\n![GitHub release (latest by date including pre-releases)](https://img.shields.io/github/v/release/danhje/pdrepr?include_prereleases)\n![PyPI](https://img.shields.io/pypi/v/pdrepr)\n\n## Motivation\n\nI was tired of having to manually construct DataFrames to be used in testing, especially the reference object to be compared with the resulting DF. With this package, such a code snipped can be created from the resulting DF.\n\n\n## Installation\n\nUsing poetry:\n\n```shell\npoetry add pdrepr\n```\n\nUsing pipenv:\n\n```shell\npipenv install pdrepr\n```\n\nUsing pip:\n\n```shell\npip install pdrepr\n```\n",
    'author': 'Daniel Hjertholm',
    'author_email': 'daniel.hjertholm@icloud.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/danhje/pdrepr',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
